import type { Startable } from '@libp2p/interfaces';
import type { Components } from '@libp2p/interfaces/components';
export interface AutoDiallerInit {
    /**
     * Should preemptively guarantee connections are above the low watermark
     */
    enabled?: boolean;
    /**
     * The minimum number of connections to avoid pruning
     */
    minConnections?: number;
    /**
     * How often, in milliseconds, it should preemptively guarantee connections are above the low watermark
     */
    autoDialInterval?: number;
}
export declare class AutoDialler implements Startable {
    private readonly components;
    private readonly options;
    private running;
    private autoDialTimeout?;
    /**
     * Proactively tries to connect to known peers stored in the PeerStore.
     * It will keep the number of connections below the upper limit and sort
     * the peers to connect based on wether we know their keys and protocols.
     */
    constructor(components: Components, init: AutoDiallerInit);
    isStarted(): boolean;
    /**
     * Starts the auto dialer
     */
    start(): Promise<void>;
    /**
     * Stops the auto dialler
     */
    stop(): Promise<void>;
    _autoDial(): Promise<void>;
}
//# sourceMappingURL=auto-dialler.d.ts.map