import { Multiaddr } from '@multiformats/multiaddr';
import { TimeoutController } from 'timeout-abort-controller';
import { DialRequest } from './dial-request.js';
import type { Connection } from '@libp2p/interfaces/connection';
import type { AbortOptions, Startable } from '@libp2p/interfaces';
import type { PeerId } from '@libp2p/interfaces/peer-id';
import type { Components } from '@libp2p/interfaces/components';
import type { Dialer, DialerInit } from '@libp2p/interfaces/dialer';
export interface DialTarget {
    id: string;
    addrs: Multiaddr[];
}
export interface PendingDial {
    dialRequest: DialRequest;
    controller: TimeoutController;
    promise: Promise<Connection>;
    destroy: () => void;
}
export interface PendingDialTarget {
    resolve: (value: any) => void;
    reject: (err: Error) => void;
}
export declare class DefaultDialer implements Dialer, Startable {
    private readonly components;
    private readonly addressSorter;
    private readonly maxAddrsToDial;
    private readonly timeout;
    private readonly maxDialsPerPeer;
    tokens: number[];
    pendingDials: Map<string, PendingDial>;
    pendingDialTargets: Map<string, PendingDialTarget>;
    private started;
    constructor(components: Components, init?: DialerInit);
    isStarted(): boolean;
    start(): Promise<void>;
    /**
     * Clears any pending dials
     */
    stop(): Promise<void>;
    /**
     * Connects to a given `peer` by dialing all of its known addresses.
     * The dial to the first address that is successfully able to upgrade a connection
     * will be used.
     */
    dial(peer: PeerId | Multiaddr, options?: AbortOptions): Promise<Connection>;
    dialProtocol(peer: PeerId | Multiaddr, protocols: string | string[], options?: AbortOptions): Promise<import("@libp2p/interfaces/connection").ProtocolStream>;
    /**
     * Connects to a given `peer` by dialing all of its known addresses.
     * The dial to the first address that is successfully able to upgrade a connection
     * will be used.
     */
    _createCancellableDialTarget(peer: PeerId): Promise<DialTarget>;
    /**
     * Creates a DialTarget. The DialTarget is used to create and track
     * the DialRequest to a given peer.
     * If a multiaddr is received it should be the first address attempted.
     * Multiaddrs not supported by the available transports will be filtered out.
     */
    _createDialTarget(peer: PeerId): Promise<DialTarget>;
    /**
     * Creates a PendingDial that wraps the underlying DialRequest
     */
    _createPendingDial(dialTarget: DialTarget, options?: AbortOptions): PendingDial;
    getTokens(num: number): number[];
    releaseToken(token: number): void;
    /**
     * Resolve multiaddr recursively
     */
    _resolve(ma: Multiaddr): Promise<Multiaddr[]>;
    /**
     * Resolve a given multiaddr. If this fails, an empty array will be returned
     */
    _resolveRecord(ma: Multiaddr): Promise<Multiaddr[]>;
}
//# sourceMappingURL=index.d.ts.map