import type { PeerId } from '@libp2p/interfaces/peer-id';
import type { Startable } from '@libp2p/interfaces';
import type { Stream } from '@libp2p/interfaces/connection';
import type { IncomingStreamData } from '@libp2p/interfaces/registrar';
import type { Components } from '@libp2p/interfaces/components';
export interface FetchInit {
    protocolPrefix: string;
}
export interface HandleMessageOptions {
    stream: Stream;
    protocol: string;
}
export interface LookupFunction {
    (key: string): Promise<Uint8Array | null>;
}
/**
 * A simple libp2p protocol for requesting a value corresponding to a key from a peer.
 * Developers can register one or more lookup function for retrieving the value corresponding to
 * a given key.  Each lookup function must act on a distinct part of the overall key space, defined
 * by a fixed prefix that all keys that should be routed to that lookup function will start with.
 */
export declare class FetchService implements Startable {
    private readonly components;
    private readonly lookupFunctions;
    private readonly protocol;
    private started;
    constructor(components: Components, init: FetchInit);
    start(): Promise<void>;
    stop(): Promise<void>;
    isStarted(): boolean;
    /**
     * Sends a request to fetch the value associated with the given key from the given peer
     */
    fetch(peer: PeerId, key: string): Promise<Uint8Array | null>;
    /**
     * Invoked when a fetch request is received.  Reads the request message off the given stream and
     * responds based on looking up the key in the request via the lookup callback that corresponds
     * to the key's prefix.
     */
    handleMessage(data: IncomingStreamData): Promise<void>;
    /**
     * Given a key, finds the appropriate function for looking up its corresponding value, based on
     * the key's prefix.
     */
    _getLookupFunction(key: string): LookupFunction | undefined;
    /**
     * Registers a new lookup callback that can map keys to values, for a given set of keys that
     * share the same prefix
     */
    registerLookupFunction(prefix: string, lookup: LookupFunction): void;
    /**
     * Registers a new lookup callback that can map keys to values, for a given set of keys that
     * share the same prefix.
     */
    unregisterLookupFunction(prefix: string, lookup?: LookupFunction): void;
}
//# sourceMappingURL=index.d.ts.map