import type { Transport, TransportManager, TransportManagerEvents } from '@libp2p/interfaces/transport';
import type { Multiaddr } from '@multiformats/multiaddr';
import type { Connection } from '@libp2p/interfaces/connection';
import { AbortOptions, EventEmitter, Startable } from '@libp2p/interfaces';
import type { Components } from '@libp2p/interfaces/components';
export interface TransportManagerInit {
    faultTolerance?: FAULT_TOLERANCE;
}
export declare class DefaultTransportManager extends EventEmitter<TransportManagerEvents> implements TransportManager, Startable {
    private readonly components;
    private readonly transports;
    private readonly listeners;
    private readonly faultTolerance;
    private started;
    constructor(components: Components, init?: TransportManagerInit);
    /**
     * Adds a `Transport` to the manager
     */
    add(transport: Transport): void;
    isStarted(): boolean;
    start(): Promise<void>;
    /**
     * Stops all listeners
     */
    stop(): Promise<void>;
    /**
     * Dials the given Multiaddr over it's supported transport
     */
    dial(ma: Multiaddr, options?: AbortOptions): Promise<Connection>;
    /**
     * Returns all Multiaddr's the listeners are using
     */
    getAddrs(): Multiaddr[];
    /**
     * Returns all the transports instances
     */
    getTransports(): Transport[];
    /**
     * Finds a transport that matches the given Multiaddr
     */
    transportForMultiaddr(ma: Multiaddr): Transport | undefined;
    /**
     * Starts listeners for each listen Multiaddr
     */
    listen(addrs: Multiaddr[]): Promise<void>;
    /**
     * Removes the given transport from the manager.
     * If a transport has any running listeners, they will be closed.
     */
    remove(key: string): Promise<void>;
    /**
     * Removes all transports from the manager.
     * If any listeners are running, they will be closed.
     *
     * @async
     */
    removeAll(): Promise<void>;
}
/**
 * Enum Transport Manager Fault Tolerance values
 */
export declare enum FAULT_TOLERANCE {
    /**
     * should be used for failing in any listen circumstance
     */
    FATAL_ALL = 0,
    /**
     * should be used for not failing when not listening
     */
    NO_FATAL = 1
}
//# sourceMappingURL=transport-manager.d.ts.map